 [![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit) [![PyPI version](https://badge.fury.io/py/datamaestro-text.svg)](https://badge.fury.io/py/datamaestro-text)

# Text-related datasets

This [datamaestro](https://github.com/bpiwowar/datasets) plugin covers text-related datasets:

- Information Retrieval
- Natural Language Processing tasks

The list of available datasets and usage instruction can be found in the [documentation](https://datamaestro-text.readthedocs.io/).
